@@ -1,5 +1,5 @@
 package Pod::Weaver::Weaver::License;
-our $VERSION = '2.000';
+our $VERSION = '2.001';
 
 use Moose;
 with 'Pod::Weaver::Role::Weaver';
@@ -15,7 +15,7 @@ sub weave {
   my $notice = $arg->{license}->notice;
   chomp $notice;
 
-  $self->weaver->output_pod->push(
+  $self->weaver->output_pod->children->push(
     Pod::Elemental::Element::Command->new({
       type     => 'command',
       command  => 'head1',
@@ -35,13 +35,16 @@ no Moose;
 1;
 
 __END__
+
+=pod
+
 =head1 NAME
 
 Pod::Weaver::Weaver::License - add a license notice
 
 =head1 VERSION
 
-version 2.000
+version 2.001
 
 =head1 AUTHOR
 
@@ -49,8 +52,11 @@ version 2.000
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2008 by Ricardo SIGNES.
+This software is copyright (c) 2009 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as perl itself.
 
+=cut 
+
+
